package dune-rpc

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Dune_rpc_private.Compound_user_errorSource

A compound user error defines an alternative format for error messages that retains more structure. This can be used to display the errors in richer form by RPC clients.

A compound user error defines an alternative format for error messages that retains more structure. This can be used to display the errors in richer form by RPC clients.

Sourceval sexp : t Conv.value
Sourceval to_dyn : t -> Dyn.t
Sourceval make : main:Stdune.User_message.t -> related:Stdune.User_message.t list -> t

Make a t with severity as Error.

Sourceval make_with_severity : main:Stdune.User_message.t -> related:Stdune.User_message.t list -> severity:Stdune.User_message.Severity.t -> t
Sourceval parse_output : dir:Stdune.Path.t -> string -> t list