package dune-rpc

  1. Overview
  2. Docs

Module Ansi_color.RGB24Source

Sourcetype t

24-bit RGB color (true color)

Sourceval red : t -> int

red t returns the red component of the 24-bit color t.

Sourceval green : t -> int

green t returns the green component of the 24-bit color t.

Sourceval blue : t -> int

blue t returns the blue component of the 24-bit color t.

Sourceval to_int : t -> int

to_int t returns the 24-bit color as an integer in the range 0, 0xFFFFFF. Each color components consists of 8 bits.